#ifndef QT_FEATURES_Core5Compat_src_core5_qtcore5compat_config_h_H
#define QT_FEATURES_Core5Compat_src_core5_qtcore5compat_config_h_H

#define QT_FEATURE_iconv -1

#define QT_FEATURE_textcodec 1

#define QT_FEATURE_codecs 1

#define QT_FEATURE_big_codecs 1

#define QT_NO_ICONV 1

#endif // QT_FEATURES_Core5Compat_src_core5_qtcore5compat_config_h_H
